@@ -61,7 +61,8 @@ class TestAPI(testscenarios.TestWithScenarios,
         ('zookeeper', {'url': os.getenv("TOOZ_TEST_ZOOKEEPER_URL"),
                        'bad_url': 'zookeeper://localhost:1'}),
         ('etcd', {'url': os.getenv("TOOZ_TEST_ETCD_URL"),
-                  'bad_url': 'etcd://localhost:1'})
+                  'bad_url': 'etcd://localhost:1'}),
+        ('consul', {'url': os.getenv("TOOZ_TEST_CONSUL_URL")}),
     ]
 
     def assertRaisesAny(self, exc_classes, callable_obj, *args, **kwargs):
@@ -671,6 +672,24 @@ class TestAPI(testscenarios.TestWithScenarios,
         self._coord.unwatch_elected_as_leader(self.group_id, self._set_event)
         self.assertEqual(0, len(self._coord._hooks_elected_leader))
 
+    def test_unwatch_elected_as_leader_callback_not_found(self):
+        self._coord.create_group(self.group_id).get()
+        self.assertRaises(tooz.coordination.WatchCallbackNotFound,
+                          self._coord.unwatch_elected_as_leader,
+                          self.group_id, lambda x: None)
+
+    def test_unwatch_join_group_callback_not_found(self):
+        self._coord.create_group(self.group_id).get()
+        self.assertRaises(tooz.coordination.WatchCallbackNotFound,
+                          self._coord.unwatch_join_group,
+                          self.group_id, lambda x: None)
+
+    def test_unwatch_leave_group_callback_not_found(self):
+        self._coord.create_group(self.group_id).get()
+        self.assertRaises(tooz.coordination.WatchCallbackNotFound,
+                          self._coord.unwatch_leave_group,
+                          self.group_id, lambda x: None)
+
     def test_get_lock(self):
         lock = self._coord.get_lock(self._get_random_uuid())
         self.assertTrue(lock.acquire())
@@ -868,6 +887,13 @@ class TestAPI(testscenarios.TestWithScenarios,
     def _get_random_uuid():
         return str(uuid.uuid4()).encode('ascii')
 
+    def test_acquire_twice_no_deadlock_releasing(self):
+        name = self._get_random_uuid()
+        lock = self._coord.get_lock(name)
+        self.assertTrue(lock.acquire(blocking=False))
+        self.assertFalse(lock.acquire(blocking=False))
+        self.assertTrue(lock.release())
+
 
 class TestHook(testcase.TestCase):
     def setUp(self):
